==> haskell-case-insensitive-1.2.0.5-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-case-insensitive/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: case-insensitive
version: 1.2.0.5
id: case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
key: casei_DNSVdyEjyyl9Og6G8xHN9C
license: BSD3
copyright: 2011 Bas van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/case-insensitive
synopsis: Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.
category: Data, Text
author: Bas van Dijk
exposed: True
exposed-modules:
    Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules: Data.CaseInsensitive.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/case-insensitive-1.2.0.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/case-insensitive-1.2.0.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/case-insensitive-1.2.0.5
hs-libraries: HScase-insensitive-1.2.0.5-DNSVdyEjyyl9Og6G8xHN9C
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock
haddock-html: /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-case-insensitive-1.2.0.6-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-case-insensitive/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: case-insensitive
version: 1.2.0.6
id: case-insensitive-1.2.0.6-c798f9d7ea7ba5a96fa5679d606aad7f
key: casei_JRhTm2FU9QH5sTVvkKjo8m
license: BSD3
copyright: 2011 Bas van Dijk
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
homepage: https://github.com/basvandijk/case-insensitive
synopsis: Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.
category: Data, Text
author: Bas van Dijk
exposed: True
exposed-modules:
    Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules: Data.CaseInsensitive.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/case-insensitive-1.2.0.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/case-insensitive-1.2.0.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/case-insensitive-1.2.0.6
hs-libraries: HScase-insensitive-1.2.0.6-JRhTm2FU9QH5sTVvkKjo8m
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock
haddock-html: /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
